# Generated by Django 2.2.1 on 2019-07-14 07:02

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='WeappUser',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nickName', models.CharField(blank=True, default='NO NICKNAME', max_length=50)),
                ('avatarUrl', models.TextField(blank=True, null=True)),
                ('gender', models.IntegerField(blank=True, null=True)),
                ('city', models.CharField(blank=True, default='NO CITY', max_length=100)),
                ('province', models.CharField(blank=True, default='NO PROVINCE', max_length=100)),
                ('country', models.CharField(blank=True, default='NO COUNTRY', max_length=100)),
                ('language', models.CharField(blank=True, default='NO LANG', max_length=20)),
                ('unionId', models.CharField(blank=True, max_length=50, null=True)),
                ('sessionKey', models.CharField(blank=True, max_length=50, null=True)),
                ('token', models.CharField(max_length=32, null=True)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='weapp_user', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
